X-Git-Url: https://git.r.bdr.sh/rbdr/r.bdr.sh/blobdiff_plain/a141dd00e8129ba1e75b56cfea96d4cacff0b154..4356e493efd67f3ba62b83dcd84458e8957a4062:/swiftbar/sourcehut-builds.1m.sh
diff --git a/swiftbar/sourcehut-builds.1m.sh b/swiftbar/sourcehut-builds.1m.sh
index 6ad4340..d7ae08f 100644
--- a/swiftbar/sourcehut-builds.1m.sh
+++ b/swiftbar/sourcehut-builds.1m.sh
@@ -8,15 +8,15 @@
# curl,jq
# https://r.bdr.sh/swiftbar_scripts.html
# string(VAR_SOURCEHUT_API_TOKEN): Your sourcehut API Token.
# number(VAR_BUILD_COUNT=5): How many items to show.
# true
-# VAR_SOURCEHUT_API_TOKEN=no, VAR_BUILD_COUNT=5
+# VAR_SOURCEHUT_API_TOKEN=no, VAR_BUILD_COUNT=9
###############################################################################
# The Variables
###############################################################################
VAR_SOURCEHUT_API_TOKEN=${VAR_SOURCEHUT_API_TOKEN:-'ADD YOUR TOKEN HERE'}
-VAR_BUILD_COUNT=${VAR_BUILD_COUNT:-5}
+VAR_BUILD_COUNT=${VAR_BUILD_COUNT:-10}
###############################################################################
# The Code
@@ -8,15 +8,15 @@
# https://r.bdr.sh/swiftbar_scripts.html
# string(VAR_SOURCEHUT_API_TOKEN): Your sourcehut API Token.
-# number(VAR_BUILD_COUNT=5): How many items to show.
+# number(VAR_BUILD_COUNT=10): How many items to show.
# true